summaryrefslogtreecommitdiffstats
path: root/k9author/menuEdit.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'k9author/menuEdit.cpp')
-rw-r--r--k9author/menuEdit.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/k9author/menuEdit.cpp b/k9author/menuEdit.cpp
index d9a74c4..3f65a27 100644
--- a/k9author/menuEdit.cpp
+++ b/k9author/menuEdit.cpp
@@ -26,11 +26,11 @@
#include "kcolorbutton.h"
/*
* Constructs a menuEdit as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
-menuEdit::menuEdit( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+menuEdit::menuEdit( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
if ( !name )
setName( "menuEdit" );
@@ -26,11 +26,11 @@
#include "kcolorbutton.h"
/*
- * Constructs a menuEdit as a child of 'tqparent', with the
+ * Constructs a menuEdit as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/